powered by
A confidence interval for the mean
meanConfInt(vector = NULL, mean = NULL, sd = NULL, n = NULL, se = NULL, conf.level = 0.95)# S3 method for meanConfInt print(x, digits = 2, ...)
# S3 method for meanConfInt print(x, digits = 2, ...)
A vector with raw data points - either specify this or a mean and then either an sd and n or an se.
A mean.
A standard deviation and sample size; can be specified to compute the standard error.
The standard error (cna be specified instead of `sd` and `n`).
The confidence level of the interval.
Respectively the object to print, the number of digits to round to, and any additonal arguments to pass on to the `print` function.
And object with elements `input`, `intermediate`, and `output`, where `output` holds the result in list `ci`.
# NOT RUN { meanConfInt(mean=5, sd=2, n=20); # }
Run the code above in your browser using DataLab